pub struct Ssh {
pub client_version_exchange: Option<SshVersionExchange>,
pub server_version_exchange: Option<SshVersionExchange>,
pub key_exchange: Option<SshKeyExchange>,
pub client_dh_key_exchange: Option<SshDhInit>,
pub server_dh_key_exchange: Option<SshDhResponse>,
pub client_new_keys: Option<SshNewKeys>,
pub server_new_keys: Option<SshNewKeys>,
/* private fields */
}Expand description
Parsed SSH handshake contents.
Fields
client_version_exchange: Option<SshVersionExchange>Client protocol version exchange message.
server_version_exchange: Option<SshVersionExchange>Server protocol version exchange message.
key_exchange: Option<SshKeyExchange>Key Exchange message.
client_dh_key_exchange: Option<SshDhInit>Client Diffie-Hellman Key Exchange message.
server_dh_key_exchange: Option<SshDhResponse>Server Diffie-Hellman Key Exchange message.
client_new_keys: Option<SshNewKeys>Client New Keys message.
server_new_keys: Option<SshNewKeys>Server New Keys message.
Implementations
Sourceimpl Ssh
impl Ssh
Sourcepub fn protocol_version_ctos(&self) -> &str
pub fn protocol_version_ctos(&self) -> &str
Returns the SSH protocol version used by the client (e.g. 2.0).
Sourcepub fn software_version_ctos(&self) -> &str
pub fn software_version_ctos(&self) -> &str
Returns the SSH software version used by the client.
Sourcepub fn comments_ctos(&self) -> &str
pub fn comments_ctos(&self) -> &str
Returns comments, or "" if there are no comments, in the protocol version exchange message sent from the client.
Sourcepub fn protocol_version_stoc(&self) -> &str
pub fn protocol_version_stoc(&self) -> &str
Returns the SSH protocol version used by the server (e.g. 2.0).
Sourcepub fn software_version_stoc(&self) -> &str
pub fn software_version_stoc(&self) -> &str
Returns the SSH software version used by the server.
Sourcepub fn comments_stoc(&self) -> &str
pub fn comments_stoc(&self) -> &str
Returns comments, or "" if there are no comments, in the protocol version exchange message sent from the server.
Returns the cookie used in SSH key exchange.
Sourcepub fn kex_algs_stoc(&self) -> Vec<String>
pub fn kex_algs_stoc(&self) -> Vec<String>
Returns the key exchange algorithms used in SSH key exchange.
Sourcepub fn server_host_key_algs_stoc(&self) -> Vec<String>
pub fn server_host_key_algs_stoc(&self) -> Vec<String>
Returns the algorithms supported for the server host key.
Sourcepub fn encryption_algs_ctos(&self) -> Vec<String>
pub fn encryption_algs_ctos(&self) -> Vec<String>
Returns the symmetric encryption algorithms (ciphers) supported by the client.
Sourcepub fn encryption_algs_stoc(&self) -> Vec<String>
pub fn encryption_algs_stoc(&self) -> Vec<String>
Returns the symmetric encryption algorithms (ciphers) supported by the server.
Sourcepub fn mac_algs_ctos(&self) -> Vec<String>
pub fn mac_algs_ctos(&self) -> Vec<String>
Returns the MAC algorithms supported by the client.
Sourcepub fn mac_algs_stoc(&self) -> Vec<String>
pub fn mac_algs_stoc(&self) -> Vec<String>
Returns the MAC algorithms supported by the server.
Sourcepub fn compression_algs_ctos(&self) -> Vec<String>
pub fn compression_algs_ctos(&self) -> Vec<String>
Returns the compression algorithms supported by the client.
Sourcepub fn compression_algs_stoc(&self) -> Vec<String>
pub fn compression_algs_stoc(&self) -> Vec<String>
Returns the compression algorithms supported by the server.
Sourcepub fn languages_ctos(&self) -> Vec<String>
pub fn languages_ctos(&self) -> Vec<String>
Returns the language tags (if any) supported by the client.
Sourcepub fn languages_stoc(&self) -> Vec<String>
pub fn languages_stoc(&self) -> Vec<String>
Returns the language tags (if any) supported by the server.